@@ -17,11 +17,11 @@ function(data, colSNPs, sort=FALSE, info, sep="/", ...)
      pos <- temp$pos 
      info <- temp$dataSorted
      temp <- data[, pos, drop=FALSE]
-     dataSNPs <- lapply(temp, snp, sep = sep, ...)
+     dataSNPs <- mclapply(temp, snp, sep = sep, ...)
    }
  else
    { 
-    dataSNPs <- lapply(data[,colSNPs, drop=FALSE],snp,sep=sep, ...)
+    dataSNPs <- mclapply(data[,colSNPs, drop=FALSE],snp,sep=sep, ...)
    }
 
  dataSNPs<-data.frame(dataSNPs) 
